diff --git a/src/warden-client/doc/example-info.pl.txt b/src/warden-client/doc/example-info.pl.txt
index a4c1adaeca06018383cc0f4c1c5252362b742392..21114643ac10688b422ff3662d5e1f2c3a4b3d66 100755
--- a/src/warden-client/doc/example-info.pl.txt
+++ b/src/warden-client/doc/example-info.pl.txt
@@ -23,7 +23,7 @@ my $warden_path = '/home/soukal/pokus/warden/warden-client/';
 # Inclusion of warden-client receiving functionality
 require $warden_path . '/lib/WardenClientCommon.pm';
 
-my @clients = WardenClientCommon::getClientInfo($warden_path);
+my @clients = WardenClientCommon::getClientsInfo($warden_path) or exit 1; # receive data or exit
 
 print "+---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+\n";
 print "| Client ID  | Hostname                       | Registered          | Requestor               | Service                   | CT | Type            | ROE  | Description tags                                   | IP Net Client      |\n";
diff --git a/src/warden-client/lib/WardenClientCommon.pm b/src/warden-client/lib/WardenClientCommon.pm
index efda17a69798244f7b277b2d1d18e35dc3a12f69..5debf2391df550e1fcc660c893cac912f2900d66 100755
--- a/src/warden-client/lib/WardenClientCommon.pm
+++ b/src/warden-client/lib/WardenClientCommon.pm
@@ -140,9 +140,9 @@ sub c2s
 }
 
 #-------------------------------------------------------------------------------
 # getClientInfo - retrieve information about other clients from Warden server
 #-------------------------------------------------------------------------------
-sub getClientInfo 
+sub getClientsInfo 
 {
   my $warden_path = shift;
@@ -140,9 +140,9 @@ sub c2s
 
 #-------------------------------------------------------------------------------
-# getClientInfo - retrieve information about other clients from Warden server
+# getClientsInfo - retrieve information about other clients from Warden server
 #-------------------------------------------------------------------------------